Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Scheduler ¶
type Scheduler struct {
// contains filtered or unexported fields
}
Scheduler polls the store for due scheduled jobs and runs them.
func NewScheduler ¶
NewScheduler creates a new Scheduler.
func (*Scheduler) CalculateNextRun ¶
CalculateNextRun computes the next run time for a cron expression.
func (*Scheduler) RecoverMissed ¶
RecoverMissed checks for jobs that missed their next_run_at and runs them once.
Click to show internal directories.
Click to hide internal directories.